#regression testing of Snapcount's high level function using pre-determined correct data

library(snapcount)
#assumed to be in the same directory as the RDA files
###Merge function

sb <- SnaptronQueryBuilder$new()

urls1=list("http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr1:1879786-1879786&either=2&rfilter=strand:-",
           "http://snaptron.cs.jhu.edu/tcga/snaptron?regions=chr1:1879786-1879786&either=2&rfilter=strand:-")

sbs1<-lapply(urls1, function(g) { sb$from_url(g)$clone(deep=TRUE) })

ju<-junction_union(sbs1[[1]],sbs1[[2]])

load(file="test_junction_union_output.rda")
all.equal(ju,test_junction_union_output)

###JIR Function
sb1 <- SnaptronQueryBuilder$new()
sb1<-sb1$from_url("http://snaptron.cs.jhu.edu/srav2/snaptron?regions=chr2:29446395-30142858&contains=1&rfilter=strand:-")
sb2 <- SnaptronQueryBuilder$new()
sb2<-sb2$from_url("http://snaptron.cs.jhu.edu/srav2/snaptron?regions=chr2:29416789-29446394&contains=1&rfilter=strand:-")
jir<-junction_inclusion_ratio(list(sb1),list(sb2))
load(file="test_jir_output.rda")
all.equal(jir,test_jir_output)

###PSI Function

inclusion_group1 <- SnaptronQueryBuilder$new()
inclusion_group1 <- inclusion_group1$from_url("http://snaptron.cs.jhu.edu/srav2/snaptron?regions=chr1:94468008-94472172&exact=1&rfilter=strand:+")
inclusion_group2 <- SnaptronQueryBuilder$new()
inclusion_group2 <- inclusion_group2$from_url("http://snaptron.cs.jhu.edu/srav2/snaptron?regions=chr1:94472243-94475142&exact=1&rfilter=strand:+")
exclusion_group <- SnaptronQueryBuilder$new()
exclusion_group <- exclusion_group$from_url("http://snaptron.cs.jhu.edu/srav2/snaptron?regions=chr1:94468008-94475142&exact=1&rfilter=strand:+")

psi<-percent_spliced_in(list(inclusion_group1), list(inclusion_group2), list(exclusion_group), min_count=1)
#should be -1
psi[which(sample_id==16033),]
#wrong_ids<-read.table(file="psi.diff2.bad_ids",sep="\t",header=FALSE)
psi2<-psi
#psi2[which(sample_id %in% wrong_ids$V1),"psi"] <- -1
load(file="test_psi_output.rda")
all.equal(psi2,test_psi_output)


###TS Function
inclusion_group1 <- SnaptronQueryBuilder$new()
inclusion_group1<-inclusion_group1$from_url("http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr4:20763023-20763023&either=2&rfilter=strand:-")
inclusion_group2 <- SnaptronQueryBuilder$new()
inclusion_group2<-inclusion_group2$from_url("http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr4:20763098-20763098&either=1&rfilter=strand:-")

ts<-tissue_specificity(list(inclusion_group1, inclusion_group2))
#fix NA issue and remove group column
#ts2<-ts[,c("sample_id","shared","tissue")]
#na_samples=c(50764,50951,51766,53549,54089)
#ts2[which(tissue=="0"),"tissue"]<-"NA"
load(file="test_ts_output.rda")
all.equal(ts,test_ts_output)


###SSC Function
#sb <- SnaptronQueryBuilder$new()
#urls1=list("http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr1:1879786-1879786&either=2&rfilter=strand:-",
#           "http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr1:9664595-9664595&either=2&rfilter=strand:+",
#           "http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr6:32831148-32831148&either=2&rfilter=strand:-")
#urls2=c("http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr1:1879903-1879903&either=1&rfilter=strand:-",
#        "http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr1:9664759-9664759&either=1&rfilter=strand:+",
#        "http://snaptron.cs.jhu.edu/gtex/snaptron?regions=chr6:32831182-32831182&either=1&rfilter=strand:-")

#sbs1<-lapply(urls1, function(g) { sb$from_url(g)$clone(deep=TRUE) })
#sbs2<-lapply(urls2, function(g) { sb$from_url(g)$clone(deep=TRUE) })
#ssc_input<-lapply(1:length(sbs1), function(g) { list(sbs1[[g]], sbs2[[g]])})
#ssc_output<-shared_sample_counts(ssc_input)

#####still having the g2$sample_id problem
#Shared Sample Count (SSC) high level function fails
#> ssc_output<-shared_sample_counts(ssc_input)
#Error in g2$sample_id : $ operator is invalid for atomic vectors
#In addition: Warning message:
#  In parallel::mclapply(groups, count_samples, summarize = summarize,  :
#                          all scheduled cores encountered errors in user code

